/*******************************************************************************
* File Name: SCB_1_PM.c
* Version 1.0
*
* Description:
*  This file provides the source code to the Power Management support for
*  the SCB Component.
*
* Note:
*
********************************************************************************
* Copyright 2013, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "SCB_1.h"

#if(SCB_1_SCB_MODE_I2C_INC)
    #include "SCB_1_I2C_PVT.h"
#endif /* (SCB_1_SCB_MODE_I2C_INC) */

#if(SCB_1_SCB_MODE_SPI_INC || SCB_1_SCB_MODE_UART_INC)
    #include "SCB_1_SPI_UART_PVT.h"
#endif /* (SCB_1_SCB_MODE_SPI_INC || SCB_1_SCB_MODE_UART_INC) */


/***************************************
*   Backup Structure declaration
***************************************/

SCB_1_BACKUP_STRUCT SCB_1_backup =
{
    0u, /* enableState */
};


/*******************************************************************************
* Function Name: SCB_1_Sleep
********************************************************************************
*
* Summary:
*  Calls SaveConfig function fucntion for selected mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SCB_1_Sleep(void)
{
    SCB_1_backup.enableState = (uint8) SCB_1_GET_CTRL_ENABLED;

    #if(SCB_1_SCB_MODE_UNCONFIG_CONST_CFG)

        if(SCB_1_SCB_MODE_I2C_RUNTM_CFG)
        {
            SCB_1_I2CSaveConfig();
        }
        else if(SCB_1_SCB_MODE_SPI_RUNTM_CFG)
        {
            SCB_1_SpiSaveConfig();
        }
        else if(SCB_1_SCB_MODE_UART_RUNTM_CFG)
        {
            SCB_1_UartSaveConfig();
        }
        else
        {
            /* Unknown mode: do nothing */
        }

    #elif(SCB_1_SCB_MODE_I2C_CONST_CFG)
        SCB_1_I2CSaveConfig();

    #elif(SCB_1_SCB_MODE_SPI_CONST_CFG)
        SCB_1_SpiSaveConfig();

    #elif(SCB_1_SCB_MODE_UART_CONST_CFG)
        SCB_1_UartSaveConfig();

    #else
        /* Do nothing */

    #endif /* (SCB_1_SCB_MODE_UNCONFIG_CONST_CFG) */

    if(0u != SCB_1_backup.enableState)
    {
        SCB_1_Stop();
    }
}


/*******************************************************************************
* Function Name: SCB_1_Wakeup
********************************************************************************
*
* Summary:
*  Calls RestoreConfig function fucntion for selected mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SCB_1_Wakeup(void)
{
    #if(SCB_1_SCB_MODE_UNCONFIG_CONST_CFG)

        if(SCB_1_SCB_MODE_I2C_RUNTM_CFG)
        {
            SCB_1_I2CRestoreConfig();
        }
        else if(SCB_1_SCB_MODE_SPI_RUNTM_CFG)
        {
            SCB_1_SpiRestoreConfig();
        }
        else if(SCB_1_SCB_MODE_UART_RUNTM_CFG)
        {
            SCB_1_UartRestoreConfig();
        }
        else
        {
            /* Unknown mode: do nothing */
        }

    #elif(SCB_1_SCB_MODE_I2C_CONST_CFG)
        SCB_1_I2CRestoreConfig();

    #elif(SCB_1_SCB_MODE_SPI_CONST_CFG)
        SCB_1_SpiRestoreConfig();

    #elif(SCB_1_SCB_MODE_UART_CONST_CFG)
        SCB_1_UartRestoreConfig();

    #else
        /* Do nothing */

    #endif /* (SCB_1_SCB_MODE_UNCONFIG_CONST_CFG) */

    if(0u != SCB_1_backup.enableState)
    {
        SCB_1_Enable();
    }
}


/* [] END OF FILE */
